from distutils.core import setup
setup(
    name = 'nesterSV',
    version = '1.2.0',
    py_modules = ['nesterSV'],
    author = 'SanderVos2401',
    author_email = 'sandervos2401@hotmail.nl',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
